#[repr(transparent)]pub struct IsoDate(pub Date<Iso>);Expand description
An ICU4X Date object capable of containing a ISO-8601 date
Tuple Fields
0: Date<Iso>Implementations
Sourceimpl<'transparent_convert_outer> IsoDate
impl<'transparent_convert_outer> IsoDate
pub(crate) fn transparent_convert( from: &'transparent_convert_outer Date<Iso>, ) -> &'transparent_convert_outer Self
Sourceimpl IsoDate
impl IsoDate
Sourcepub fn create(
year: i32,
month: u8,
day: u8,
) -> Result<Box<IsoDate>, CalendarError>
pub fn create( year: i32, month: u8, day: u8, ) -> Result<Box<IsoDate>, CalendarError>
Creates a new IsoDate from the specified date.
Sourcepub fn from_string(v: &DiplomatStr) -> Result<Box<IsoDate>, Rfc9557ParseError>
pub fn from_string(v: &DiplomatStr) -> Result<Box<IsoDate>, Rfc9557ParseError>
Creates a new IsoDate from an IXDTF string.
Sourcepub fn to_calendar(&self, calendar: &Calendar) -> Box<Date>
pub fn to_calendar(&self, calendar: &Calendar) -> Box<Date>
Convert this date to one in a different calendar
pub fn to_any(&self) -> Box<Date>
Sourcepub fn to_rata_die(&self) -> i64
pub fn to_rata_die(&self) -> i64
Returns this date’s Rata Die
Sourcepub fn day_of_year(&self) -> u16
pub fn day_of_year(&self) -> u16
Returns the 1-indexed day in the year for this date
Sourcepub fn day_of_month(&self) -> u8
pub fn day_of_month(&self) -> u8
Returns the 1-indexed day in the month for this date
Sourcepub fn day_of_week(&self) -> Weekday
pub fn day_of_week(&self) -> Weekday
Returns the day in the week for this day
Sourcepub fn week_of_year(&self) -> IsoWeekOfYear
pub fn week_of_year(&self) -> IsoWeekOfYear
Returns the week number in this year, using week data
Sourcepub fn year(&self) -> i32
pub fn year(&self) -> i32
Returns the year number in the current era for this date
For calendars without an era, returns the extended year
Sourcepub fn is_in_leap_year(&self) -> bool
pub fn is_in_leap_year(&self) -> bool
Returns if the year is a leap year for this date
Sourcepub fn months_in_year(&self) -> u8
pub fn months_in_year(&self) -> u8
Returns the number of months in the year represented by this date
Sourcepub fn days_in_month(&self) -> u8
pub fn days_in_month(&self) -> u8
Returns the number of days in the month represented by this date
Sourcepub fn days_in_year(&self) -> u16
pub fn days_in_year(&self) -> u16
Returns the number of days in the year represented by this date